pub fn dot_general_into_uninit<T: Scalar>(
c: &mut RawStridedMut<'_, MaybeUninit<T>>,
a: &StridedView<'_, T>,
b: &StridedView<'_, T>,
config: &DotGeneralConfig<'_>,
alpha: T,
ctx: &ExecContext,
) -> Result<()>Expand description
Compute dot-general into a genuinely uninitialized destination.
The destination is only exposed as initialized after this function returns
Ok(()); holes in a strided backing allocation are never touched.